@@ -132,7 +132,7 @@ class Render:
         self.__render()
 
     def draw_fade_out(self, duration):
-        alpha = 255 / duration
+        alpha = int(255 / duration)
         size = self.drawing_surface.get_size()
         surf = pygame.Surface(size, pygame.SRCALPHA)
         surf.fill((0, 0, 0, alpha))
